==> gottet_1.1.9.orig.tar.gz: gottet-1.1.9/translations/gottet_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Czy chcesz zakończyć bieżącą grę?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Wstrzymane&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Kliknij, aby wznowić grę.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Koniec gry!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Kliknij, aby rozpocząć nową grę.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Gottet Scores</source>
        <translation>Wyniki Gottet</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Linii</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Kliknij, aby rozpocząć nową grę.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowa</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Wznów</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Wyniki</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Następny element</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Usuniętych linii</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>A tetris clone I made for my wife</source>
        <translation>Klon tetrisa, którego zrobiłem dla mojej żony</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Prawo autorskie &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> gottet_1.2.4.orig.tar.gz: gottet-1.2.4/translations/gottet_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Board</name>
    <message>
        <source>Question</source>
        <translation>Pytanie</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Czy chcesz zakończyć bieżącą grę?</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Paused&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to resume playing.</source>
        <translation>&lt;big&gt;&lt;b&gt;Wstrzymane&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Kliknij, aby wznowić grę.</translation>
    </message>
    <message>
        <source>&lt;big&gt;&lt;b&gt;Game Over!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Click to start a new game.</source>
        <translation>&lt;big&gt;&lt;b&gt;Koniec gry!&lt;/b&gt;&lt;/big&gt;&lt;br&gt;Kliknij, aby rozpocząć nową grę.</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Wybierz język programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Język systemowy&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Proszę ponownie uruchomić ten program, aby zastosować zmianę języka.</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Lines</source>
        <translation>Linii</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Gottet</source>
        <translation>Gottet</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Kliknij, aby rozpocząć nową grę.</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Gra</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nowa</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Wyniki</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Zakończ</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ustawienia</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Język programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Next Piece</source>
        <translation>Następny element</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Removed Lines</source>
        <translation>Usuniętych linii</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Wynik</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott.</source>
        <translation>Prawo autorskie &amp;copy; 2008-%1 Graeme Gott.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Wydano na licencji &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A simple falling blocks game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
